@@ -1,5 +1,10 @@
 .onLoad <- function(libname, pkgname) {
 
+  .auth <<- gargle::AuthState$new(
+    package     = "googlesheets4",
+    auth_active = TRUE
+  )
+
   if (identical(Sys.getenv("IN_PKGDOWN"), "true") &&
       gargle:::secret_can_decrypt("googlesheets4") &&
       !is.null(curl::nslookup("sheets.googleapis.com", error = FALSE))) {
