@@ -5,7 +5,9 @@
 #' where `type = "spreadsheet"`. Therefore, note that this will require auth for
 #' googledrive! See the article [Using googlesheets4 with
 #' googledrive](https://googlesheets4.tidyverse.org/articles/articles/drive-and-sheets.html)
-#' if you want to coordinate auth between googlesheets4 and googledrive.
+#' if you want to coordinate auth between googlesheets4 and googledrive. This
+#' function will emit an informational message if you are currently logged in
+#' with both googlesheets4 and googledrive, but as different users.
 #'
 #' @param ... Arguments (other than `type`, which is hard-wired as `type =
 #'   "spreadsheet"`) that are passed along to [googledrive::drive_find()].
@@ -28,5 +30,6 @@
 #'   #   dplyr::mutate(created_on = as.Date(created_on))
 #' }
 gs4_find <- function(...) {
+  check_gs4_email_is_drive_email()
   googledrive::drive_find(..., type = "spreadsheet")
 }
